==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/en_GB.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} is available. Get more information on how to update.",
    "Update notifications" : "Update notifications",
    "Channel updated" : "Channel updated",
    "The update server could not be reached since %d days to check for new updates." : "The update server could not be reached since %d days to check for new updates.",
    "Please check the Nextcloud and server log files for errors." : "Please check the Nextcloud and server log files for errors.",
    "Update to %1$s is available." : "Update to %1$s is available.",
    "Update for %1$s to version %2$s is available." : "Update for %1$s to version %2$s is available.",
    "Update for {app} to version %s is available." : "Update for {app} to version %s is available.",
    "Update notification" : "Update notification",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Displays update notifications for Nextcloud and provides the SSO for the updater.",
    "Apps with available updates" : "Apps with available updates",
    "Open updater" : "Open updater",
    "The update check is not yet finished. Please refresh the page." : "The update check is not yet finished. Please refresh the page.",
    "A non-default update server is in use to be checked for updates:" : "A non-default update server is in use to be checked for updates:",
    "Update channel:" : "Update channel:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found.",
    "Notify members of the following groups about available updates:" : "Notify members of the following groups about available updates:",
    "Only notification for app updates are available." : "Only notification for app updates are available.",
    "The selected update channel does not support updates of the server." : "The selected update channel does not support updates of the server.",
    "A new version is available: <strong>{newVersionString}</strong>" : "A new version is available: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Checked on {lastCheckedDate}",
    "Checking apps for compatible updates" : "Checking apps for compatible updates",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>All</strong> apps have an update for this version available",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> app has no update for this version available","<strong>%n</strong> apps have no update for this version available"],
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2).",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments.",
    "Could not start updater, please try the manual update" : "Could not start updater, please try the manual update",
    "A new version is available: %s" : "A new version is available: %s",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible.",
    "Download now" : "Download now",
    "Your version is up to date." : "Your version is up to date.",
    "Checked on %s" : "Checked on %s",
    "The selected update channel makes dedicated notifications for the server obsolete." : "The selected update channel makes dedicated notifications for the server obsolete."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/en_GB.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} is available. Get more information on how to update.",
    "Update notifications" : "Update notifications",
    "Channel updated" : "Channel updated",
    "The update server could not be reached since %d days to check for new updates." : "The update server could not be reached since %d days to check for new updates.",
    "Please check the Nextcloud and server log files for errors." : "Please check the Nextcloud and server log files for errors.",
    "Update to %1$s is available." : "Update to %1$s is available.",
    "Update for %1$s to version %2$s is available." : "Update for %1$s to version %2$s is available.",
    "Update for {app} to version %s is available." : "Update for {app} to version %s is available.",
    "Update notification" : "Update notification",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Displays update notifications for Nextcloud and provides the SSO for the updater.",
    "Apps with available updates" : "Apps with available updates",
    "Open updater" : "Open updater",
    "What's new?" : "What's new?",
    "The update check is not yet finished. Please refresh the page." : "The update check is not yet finished. Please refresh the page.",
    "A non-default update server is in use to be checked for updates:" : "A non-default update server is in use to be checked for updates:",
    "Update channel:" : "Update channel:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found.",
    "Notify members of the following groups about available updates:" : "Notify members of the following groups about available updates:",
    "Only notification for app updates are available." : "Only notification for app updates are available.",
    "The selected update channel does not support updates of the server." : "The selected update channel does not support updates of the server.",
    "A new version is available: <strong>{newVersionString}</strong>" : "A new version is available: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Checked on {lastCheckedDate}",
    "Checking apps for compatible updates" : "Checking apps for compatible updates",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>All</strong> apps have an update for this version available",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> app has no update for this version available","<strong>%n</strong> apps have no update for this version available"],
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments.",
    "View changelog" : "View changelog",
    "Could not start updater, please try the manual update" : "Could not start updater, please try the manual update",
    "A new version is available: %s" : "A new version is available: %s",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible.",
    "Download now" : "Download now",
    "Your version is up to date." : "Your version is up to date.",
    "Checked on %s" : "Checked on %s",
    "The selected update channel makes dedicated notifications for the server obsolete." : "The selected update channel makes dedicated notifications for the server obsolete."
},
"nplurals=2; plural=(n != 1);");
